@@ -26,6 +26,7 @@
 #include <string.h>  // for strerror
 #include <unistd.h>  // g++-4.7 wants this
 #include <string>    // for string
+#include <string_view>
 // O_BINARY does not exist on Unix/Linux, since there is no distinction
 // between text mode and binary mode files there, but if we ever got
 // this code running on Windows this would be needed.
@@ -67,7 +68,13 @@ RCPP_ENUM_TRAITS(GPB::FieldDescriptor::Type)
 #include <Rcpp.h>
 
 #include <Rdefines.h>
+#include <Rversion.h>
+#if R_VERSION < R_Version(4,6,0)
 #include <R_ext/Callbacks.h>
+#else
+#include <R_ext/ObjectTable.h>
+#endif
+
 
 /* uncomment for debugging */
 // #define RPB_DEBUG
@@ -101,26 +108,22 @@ RCPP_ENUM_TRAITS(GPB::FieldDescriptor::Type)
 #define _TRUE_ (Rboolean) TRUE
 #define _FALSE_ (Rboolean) FALSE
 
-#define GET_MESSAGE_POINTER_FROM_XP(xp) (GPB::Message*) EXTPTR_PTR(xp)
-#define GET_MESSAGE_POINTER_FROM_S4(m) \
-    (GPB::Message*) EXTPTR_PTR(GET_SLOT(m, Rf_install("pointer")))
+#define GET_MESSAGE_POINTER_FROM_XP(xp) (GPB::Message*) R_ExternalPtrAddr(xp)
+#define GET_MESSAGE_POINTER_FROM_S4(m) (GPB::Message*) R_ExternalPtrAddr(GET_SLOT(m, Rf_install("pointer")))
 
-#define GET_DESCRIPTOR_POINTER_FROM_XP(xp) (GPB::Descriptor*) EXTPTR_PTR(xp)
-#define GET_DESCRIPTOR_POINTER_FROM_S4(m) \
-    (GPB::Descriptor*) EXTPTR_PTR(GET_SLOT(m, Rf_install("pointer")))
+#define GET_DESCRIPTOR_POINTER_FROM_XP(xp) (GPB::Descriptor*) R_ExternalPtrAddr(xp)
+#define GET_DESCRIPTOR_POINTER_FROM_S4(m) (GPB::Descriptor*) R_ExternalPtrAddr(GET_SLOT(m, Rf_install("pointer")))
 
-#define GET_FIELD_DESCRIPTOR_POINTER_FROM_XP(xp) (GPB::FieldDescriptor*) EXTPTR_PTR(xp)
-#define GET_FIELD_DESCRIPTOR_POINTER_FROM_S4(m) \
-    (GPB::FieldDescriptor*) EXTPTR_PTR(GET_SLOT(m, Rf_install("pointer")))
+#define GET_FIELD_DESCRIPTOR_POINTER_FROM_XP(xp) (GPB::FieldDescriptor*) R_ExternalPtrAddr(xp)
+#define GET_FIELD_DESCRIPTOR_POINTER_FROM_S4(m) (GPB::FieldDescriptor*) R_ExternalPtrAddr(GET_SLOT(m, Rf_install("pointer")))
 
-#define GET_ENUM_VALUE_DESCRIPTOR_POINTER_FROM_XP(xp) (GPB::EnumValueDescriptor*) EXTPTR_PTR(xp)
-#define GET_ENUM_VALUE_DESCRIPTOR_POINTER_FROM_S4(m) \
-    (GPB::EnumValueDescriptor*) EXTPTR_PTR(GET_SLOT(m, Rf_install("pointer")))
+#define GET_ENUM_VALUE_DESCRIPTOR_POINTER_FROM_XP(xp) (GPB::EnumValueDescriptor*) R_ExternalPtrAddr(xp)
+#define GET_ENUM_VALUE_DESCRIPTOR_POINTER_FROM_S4(m) (GPB::EnumValueDescriptor*) R_ExternalPtrAddr(GET_SLOT(m, Rf_install("pointer")))
 
 #define COPYSTRING(s) s
 #define THROW_SOCKET_ERROR(message) Rf_error("%s : %s", message, strerror(sockerrno))
 
-#define XPP EXTPTR_PTR
+#define XPP R_ExternalPtrAddr
 
 #define NEW_S4_OBJECT(CLAZZ)                          \
     SEXP oo = PROTECT(NEW_OBJECT(MAKE_CLASS(CLAZZ))); \
@@ -141,7 +144,7 @@ RcppExport SEXP newProtoMessage(SEXP);
 RcppExport SEXP getProtobufDescriptor(SEXP);
 RcppExport SEXP getExtensionDescriptor(SEXP);
 RcppExport SEXP readProtoFiles_cpp(SEXP, SEXP);
-RcppExport Rboolean isMessage(SEXP, const char*);
+RcppExport Rboolean isMessage(SEXP, std::string_view);
 RcppExport GPB::FieldDescriptor* getFieldDescriptor(const GPB::Message*, SEXP);
 
 /* in extractors.cpp */
